@@ -3,6 +3,7 @@
 # internal:
 from fdroid_mirror_monitor import repo, mirror, history, website
 from fdroid_mirror_monitor.utils import get_logger, geoip, get_own_ip, get_mirrors_readme
+
 # stdlibs
 from datetime import datetime, timezone
 from importlib.metadata import metadata
@@ -17,39 +18,31 @@ import time
 
 def main():
     parser = argparse.ArgumentParser(prog='fdroid_mirror_monitor', description=metadata(__package__)['Summary'])
-    parser.add_argument('--no_history',
-                        help='''don't create history.json''',
-                        action='store_true')
-    parser.add_argument('--no_html',
-                        help='''don't create htmls''',
-                        action='store_true')
-    parser.add_argument('--html',
-                        help='create htmls from status.json file')
-    parser.add_argument('--history_url',
-                        help='URL to the the history in JSON format',
-                        default='https://marzzzello.gitlab.io/mirror-monitor/history.json')
-    parser.add_argument('-d', '--directory',
-                        help='output directory',
-                        default='public')
-    parser.add_argument('--wiki',
-                        help='Include repos from https://forum.f-droid.org/t/known-repositories/721',
-                        action='store_true')
-    parser.add_argument('-t', '--threads',
-                        help='Number of parallel threads when checking mirrors',
-                        choices=range(1, 10), type=int,
-                        default=5)
-    parser.add_argument('--timeout',
-                        help='Timeout for requests (seconds)',
-                        type=int,
-                        default=60)
-    parser.add_argument('--trim',
-                        help='Trim history entries to the last x hours',
-                        type=int,
-                        default=24*7)
-    parser.add_argument('-v', '--verbosity',
-                        help='Set verbosity level',
-                        choices=['warning', 'info', 'debug'],
-                        default='info')
+    parser.add_argument('--no_history', help='''don't create history.json''', action='store_true')
+    parser.add_argument('--no_html', help='''don't create htmls''', action='store_true')
+    parser.add_argument('--html', help='create htmls from status.json file')
+    parser.add_argument(
+        '--history_url',
+        help='URL to the the history in JSON format',
+        default='https://marzzzello.gitlab.io/mirror-monitor/history.json',
+    )
+    parser.add_argument('-d', '--directory', help='output directory', default='public')
+    parser.add_argument(
+        '--wiki', help='Include repos from https://forum.f-droid.org/t/known-repositories/721', action='store_true'
+    )
+    parser.add_argument(
+        '-t',
+        '--threads',
+        help='Number of parallel threads when checking mirrors',
+        choices=range(1, 10),
+        type=int,
+        default=5,
+    )
+    parser.add_argument('--timeout', help='Timeout for requests (seconds)', type=int, default=60)
+    parser.add_argument('--trim', help='Trim history entries to the last x hours', type=int, default=24 * 7)
+    parser.add_argument(
+        '-v', '--verbosity', help='Set verbosity level', choices=['warning', 'info', 'debug'], default='info'
+    )
     args = parser.parse_args()
 
     output_dir = path.realpath(args.directory)
@@ -77,13 +70,13 @@ def main():
     # log.debug('mirrors: %s', mirrors)
 
     # official  mirrors
-    repo_mirrors, archive_mirrors = get_mirrors_readme()
+    # repo_mirrors, archive_mirrors = get_mirrors_readme()
 
     # official repo
     official_fp = '43238D512C1E5EB2D6569F4A3AFBF5523418B82E0A3ED1552770ABB9A9C9CCAB'
     url = 'https://f-droid.org/repo'
     official_repo = repo.Repo(url, fingerprint=official_fp)
-    official_repo.set_additional_mirrors(repo_mirrors)
+    # official_repo.set_additional_mirrors(repo_mirrors)
     # success = official_repo.get_all()
     # if success is False:
     #     exit('Error: https://f-droid.org/repo')
